# dict_and_html

A lightweight solution to converting Python dictionaries into HTML tables, in
Python

Open source available on [GitHub](https://github.com/Whoeza/dict_and_html) and 
[PyPI](https://pypi.org/project/dict_and_html/).

## Installation

Install from pip:

`py -m pip install dict_and_html`

Update to the latest version from pip:

`py -m pip install --upgrade dict_and_html`

Uninstall from pip:

`py -m pip uninstall dict_and_html`

### Building from sources

Run this command from the package directory on your filesystem:

`py -m build`

## Playing around

Check and edit `example.py` for an example of how to convert dictionaries into 
HTML tables in Python with `dict_and_html`.

## Community

[Open a new issue](https://github.com/Whoeza/dict_and_html/issues) for
support.

### Special thanks to

- **namedots** - For the great help with Python imports
